# TOPSIS

Submitted By: **Sudeep Singh - 101903496**.

Type: **Package**.

Title: **TOPSIS score and ranking**.

Version: **0.0.3**.

Description: **Evaluation of alternatives based on multiple criteria using TOPSIS method.**.

---

## What is TOPSIS?

**T**echnique for **O**rder **P**reference by **S**imilarity to **I**deal **S**olution
(TOPSIS) originated in the 1980s as a multi-criteria decision making method.
TOPSIS chooses the alternative of shortest Euclidean distance from the ideal solution,
and greatest distance from the negative-ideal solution.

<br>

## How to install this package:

```
>> pip install Topsis-Sudeep-101903496
```

### In Command Prompt

```
>> topsis data.csv "1,1,1,1,2" "+,+,-,+,-" result.csv
```
"# Topsis-Sudeep-101903496"
